@@ -47,11 +47,14 @@
         # # Callback final tile classification
         # .callback(process = "Apply", event = "recovery",
         #           context = environment())
-        message("Recovery: band ",
-                paste0("'", out_band, "'", collapse = ", "),
-                " already exists.")
-        message("(If you want to produce a new image, please ",
-                "change 'output_dir' or 'version' parameters)")
+        if (.check_messages()) {
+            message("Recovery: band ",
+                    paste0("'", out_band, "'", collapse = ", "),
+                    " already exists.")
+            message("(If you want to produce a new image, please ",
+                    "change 'output_dir' or 'version' parameters)")
+        }
+
         # Create tile based on template
         feature <- .tile_eo_from_files(
             files = out_file, fid = .fi_fid(.fi(feature)),
@@ -270,12 +273,6 @@
                 band = 0, window_size = window_size
             )
         },
-        w_sum = function(m) {
-            C_kernel_sum(
-                x = as.matrix(m), ncols = img_ncol, nrows = img_nrow,
-                band = 0, window_size = window_size
-            )
-        },
         w_mean = function(m) {
             C_kernel_mean(
                 x = as.matrix(m), ncols = img_ncol, nrows = img_nrow,
@@ -288,12 +285,6 @@
                 band = 0, window_size = window_size
             )
         },
-        w_var = function(m) {
-            C_kernel_var(
-                x = as.matrix(m), ncols = img_ncol, nrows = img_nrow,
-                band = 0, window_size = window_size
-            )
-        },
         w_min = function(m) {
             C_kernel_min(
                 x = as.matrix(m), ncols = img_ncol, nrows = img_nrow,
