@@ -16,7 +16,11 @@
             call. = FALSE
         ))
     }
-
+    # Convert roi to bbox
+    lon <- stac_query$params$intersects$coordinates[,,1]
+    lat <- stac_query$params$intersects$coordinates[,,2]
+    stac_query$params$intersects <- NULL
+    stac_query$params$bbox <- c(min(lon), min(lat), max(lon), max(lat))
     # making the request
     items_info <- rstac::post_request(q = stac_query, ...)
     .check_stac_items(items_info)
