@@ -17,13 +17,13 @@
 #' Nature Communications 13, 2208 (2022).
 #' https://doi.org/10.1038/s41467-022-29838-9
 #'
-#' @param samples A `sits` tibble with time series samples.
-#' @param roi     A `sf` object (polygon) with a region of interest
-#'                for prediction.
+#' @param samples A \code{samples} training data set.
+#' @param roi     A region of interest (ROI) used to extract random
+#'   predicted points.
 #' @param n       Maximum number of samples to consider.
+#' @param crs     CRS of the \code{samples}.
 #'
-#' @return        A tibble with sample-to-sample
-#'                and sample-to-prediction distances.
+#' @return A tibble with sample-to-sample and sample-to-prediction distances.
 #'
 #' @examples
 #' if (sits_run_examples()) {
@@ -34,29 +34,31 @@
 #'     # convert to an sf object
 #'     mt_sf <- sf::read_sf(mt_shp)
 #'     # calculate sample-to-sample and sample-to-prediction distances
-#'     distances <- sits_geo_dist(samples_modis_4bands, mt_sf)
+#'     distances <- sits_geo_dist(samples = samples_modis_ndvi,
+#'     roi = mt_sf)
 #'     # plot sample-to-sample and sample-to-prediction distances
 #'     plot(distances)
 #' }
 #' @export
 #'
-sits_geo_dist <- function(samples, roi = NULL, n = 1000) {
-    stopifnot(inherits(samples, "sits"))
+sits_geo_dist <- function(samples, roi, n = 1000, crs = "EPSG:4326") {
 
+    # Pre-conditions
+    .check_samples(samples)
+    if (.has(roi)) {
+        roi <- .roi_as_sf(roi = roi, as_crs = "EPSG:4326")
+    }
+
+    # TODO: change to samples API
     samples <- samples[sample(seq_len(nrow(samples)), min(n, nrow(samples))), ]
 
-    # NOTE: sits_tibbles are always in WGS84.
-    samples_sf <- sf::st_as_sf(samples,
-        coords = c("longitude", "latitude"),
-        crs = 4326,
-        remove = FALSE
+    # Convert training samples to points
+    samples_sf <- .point_as_sf(
+        .point(x = samples, crs = crs), as_crs = "EPSG:4326"
     )
 
-    pred_sf <- sf::st_sample(roi, n)
-    pred_sf <- sf::st_as_sf(pred_sf)
-    pred_sf <- sf::st_transform(pred_sf,
-        crs = sf::st_crs(samples_sf)
-    )
+    # Get random points from roi
+    pred_sf <- sf::st_sample(x = roi, size = n)
 
     dist_ss <- .find_closest(samples_sf)
     dist_sp <- .find_closest(samples_sf, pred_sf)
@@ -72,6 +74,7 @@ sits_geo_dist <- function(samples, roi = NULL, n = 1000) {
 #'
 #' @author Alber Sanchez, \email{alber.ipia@@inpe.br}
 #' @keywords internal
+#' @noRd
 #' @description
 #' For each point in x, find the closest point in y (and their distance).
 #'
