@@ -26,14 +26,17 @@
 #'  \item{"all years": }{Plot all samples from the same location together}
 #'  \item{"together": }{Plot all samples of the same band and label together}
 #' }
-#' The plot.sits function makes an educated guess of what plot is required,
-#' based on the input data. If the input data has less than 30 samples, it
-#' will default to "all years". If there are more than 30 samples,
-#' it will default to "together".
+#' The plot function makes an educated guess of what plot is required
+#' based on the input data. If the input data has less than 30 samples or
+#' the \code{together} parameter is FALSE, it will plot only one randomly
+#' chosen sample. If the \code{together} parameter is set to TRUE or
+#' there are more than 30 samples, it will plot all samples.
 #'
-#' @param  x    Object of class "sits"
-#' @param  y    Ignored.
-#' @param ...   Further specifications for \link{plot}.
+#' @param x        Object of class "sits".
+#' @param y        Ignored.
+#' @param together A logical value indicating whether the samples should be
+#'  plotted together.
+#' @param ...      Further specifications for \link{plot}.
 #'
 #' @return A series of plot objects produced by ggplot2 showing all
 #'   time series associated to each combination of band and label,
@@ -49,12 +52,13 @@
 #' }
 #'
 #' @export
-#'
-plot.sits <- function(x, y, ...) {
+plot.sits <- function(x, y, ..., together = FALSE) {
     stopifnot(missing(y))
+    # default value is set to empty char in case null
+    .check_lgl_parameter(together)
 
     # Are there more than 30 samples? Plot them together!
-    if (nrow(x) > 30) {
+    if (together || nrow(x) > 30) {
         p <- .plot_together(x)
     }  else {
         # otherwise, take "allyears" as the default
@@ -362,6 +366,7 @@ plot.sits <- function(x, y, ...) {
 #' @param  x             Object of class "patterns".
 #' @param  y             Ignored.
 #' @param  ...           Further specifications for \link{plot}.
+#' @param  bands         Bands to be viewed (optional).
 #' @return               A plot object produced by ggplot2
 #'                       with one average pattern per label.
 #'
@@ -376,11 +381,21 @@ plot.sits <- function(x, y, ...) {
 #' }
 #' @export
 #'
-plot.patterns <- function(x, y, ...) {
+plot.patterns <- function(x, y, ..., bands = NULL) {
     stopifnot(missing(y))
     # verifies if scales package is installed
     .check_require_packages("scales")
 
+    patterns_bands <- .ts_bands(.ts(x))
+    bands <- .default(bands, patterns_bands)
+
+    .check_chr_within(
+        x = bands,
+        within = patterns_bands,
+        msg = "Invalid 'bands' parameter"
+    )
+
+    .ts(x) <- .ts_select_bands(.ts(x), bands)
     # put the time series in the data frame
     plot.df <- purrr::pmap_dfr(
         list(x$label, x$time_series),
@@ -590,8 +605,17 @@ plot.predicted <- function(x, y, ...,
 #' @param  blue          Band for blue color.
 #' @param  tile          Tile to be plotted.
 #' @param  date          Date to be plotted.
+#' @param  segments      List with segments to be shown (one per tile)
+#' @param  seg_color     Color to use for segment borders
 #' @param  palette       An RColorBrewer palette
 #' @param  rev           Reverse the color order in the palette?
+#' @param  tmap_options  List with optional tmap parameters
+#'                       tmap_max_cells (default: 1e+06)
+#'                       tmap_graticules_labels_size (default: 0.7)
+#'                       tmap_legend_title_size (default: 1.5)
+#'                       tmap_legend_text_size (default: 1.2)
+#'                       tmap_legend_bg_color (default: "white")
+#'                       tmap_legend_bg_alpha (default: 0.5)
 #'
 #' @return               A plot object with an RGB image
 #'                       or a B/W image on a color
@@ -605,9 +629,7 @@ plot.predicted <- function(x, y, ...,
 #'     cube <- sits_cube(
 #'         source = "BDC",
 #'         collection = "MOD13Q1-6",
-#'         data_dir = data_dir,
-#'         delim = "_",
-#'         parse_info = c("X1", "tile", "band", "date")
+#'         data_dir = data_dir
 #'     )
 #'     # plot NDVI band of the second date date of the data cube
 #'     plot(cube, band = "NDVI", date = sits_timeline(cube)[2])
@@ -620,9 +642,12 @@ plot.raster_cube <- function(
         green = NULL,
         blue = NULL,
         tile = x$tile[[1]],
-        date = sits_timeline(x)[[1]],
+        date = NULL,
+        segments = NULL,
+        seg_color = "lightgoldenrod",
         palette = "RdYlGn",
-        rev = FALSE
+        rev = FALSE,
+        tmap_options = NULL
 ) {
     # deal with bands
     .check_that(
@@ -646,27 +671,45 @@ plot.raster_cube <- function(
         can_repeat = FALSE,
         msg = "tile is not included in the cube"
     )
+    # filter the tile to be processed
+    tile <- .cube_filter_tiles(cube = x, tiles = tile)
+    if (purrr::is_null(date))
+        date <- .tile_timeline(tile)[[1]]
     # only one date at a time
     .check_that(length(date) == 1,
                 msg = "only one date per plot is allowed")
     # is this a valid date?
     date <- as.Date(date)
-    .check_that(date %in% sits_timeline(x),
+    .check_that(date %in% .tile_timeline(tile),
                 msg = "date is not contained in the cube timeline")
 
-    # filter the tile to be processed
-    tile <- .cube_filter_tiles(cube = x, tiles = tile)
-
     # Plot a B/W band as false color
     if (!purrr::is_null(band)) {
         .check_cube_bands(tile, bands = band)
         # plot the band as false color
-        p <- .plot_false_color(tile, band, date, palette, rev)
+        p <- .plot_false_color(
+            tile = tile,
+            band = band,
+            date = date,
+            segments = segments,
+            seg_color = seg_color,
+            palette = palette,
+            rev = rev,
+            tmap_options = tmap_options
+        )
     } else {
         # plot RGB image
         .check_cube_bands(tile, bands = c(red, green, blue))
         # plot RGB
-        p <- .plot_rgb(tile, red, green, blue, date)
+        p <- .plot_rgb(
+            tile = tile,
+            red = red,
+            green = green,
+            blue = blue,
+            date = date,
+            segments = segments,
+            seg_color = seg_color,
+            tmap_options = tmap_options)
     }
     return(p)
 }
@@ -681,6 +724,13 @@ plot.raster_cube <- function(
 #' @param labels         Labels to plot (optional).
 #' @param palette        RColorBrewer palette
 #' @param rev            Reverse order of colors in palette?
+#' @param tmap_options   List with optional tmap parameters
+#'                       tmap_max_cells (default: 1e+06)
+#'                       tmap_graticules_labels_size (default: 0.7)
+#'                       tmap_legend_title_size (default: 1.5)
+#'                       tmap_legend_text_size (default: 1.2)
+#'                       tmap_legend_bg_color (default: "white")
+#'                       tmap_legend_bg_alpha (default: 0.5)
 #' @return               A plot containing probabilities associated
 #'                       to each class for each pixel.
 #'
@@ -694,9 +744,7 @@ plot.raster_cube <- function(
 #'     cube <- sits_cube(
 #'         source = "BDC",
 #'         collection = "MOD13Q1-6",
-#'         data_dir = data_dir,
-#'         delim = "_",
-#'         parse_info = c("X1", "tile", "band", "date")
+#'         data_dir = data_dir
 #'     )
 #'     # classify a data cube
 #'     probs_cube <- sits_classify(
@@ -713,7 +761,8 @@ plot.probs_cube <- function(
         tile  = x$tile[[1]],
         labels = NULL,
         palette = "YlGnBu",
-        rev = FALSE
+        rev = FALSE,
+        tmap_options = NULL
 ) {
     # precondition
     .check_chr_contains(
@@ -729,7 +778,7 @@ plot.probs_cube <- function(
     tile <- .cube_filter_tiles(cube = x, tiles = tile)
 
     # plot the probs cube
-    p <- .plot_probs(tile, labels, palette, rev)
+    p <- .plot_probs(tile, labels, palette, rev, tmap_options)
 
     return(p)
 }
@@ -745,6 +794,13 @@ plot.probs_cube <- function(
 #' @param palette        RColorBrewer palette
 #' @param rev            Reverse order of colors in palette?
 #' @param type           Type of plot ("map" or "hist")
+#' @param tmap_options   List with optional tmap parameters
+#'                       tmap_max_cells (default: 1e+06)
+#'                       tmap_graticules_labels_size (default: 0.7)
+#'                       tmap_legend_title_size (default: 1.5)
+#'                       tmap_legend_text_size (default: 1.2)
+#'                       tmap_legend_bg_color (default: "white")
+#'                       tmap_legend_bg_alpha (default: 0.5)
 #' @return               A plot containing probabilities associated
 #'                       to each class for each pixel.
 #'
@@ -758,9 +814,7 @@ plot.probs_cube <- function(
 #'     cube <- sits_cube(
 #'         source = "BDC",
 #'         collection = "MOD13Q1-6",
-#'         data_dir = data_dir,
-#'         delim = "_",
-#'         parse_info = c("X1", "tile", "band", "date")
+#'         data_dir = data_dir
 #'     )
 #'     # classify a data cube
 #'     probs_cube <- sits_classify(
@@ -780,7 +834,8 @@ plot.variance_cube <- function(
         labels = NULL,
         palette = "YlGnBu",
         rev = FALSE,
-        type = "map"
+        type = "map",
+        tmap_options = NULL
 ) {
     # precondition
     .check_chr_contains(
@@ -799,7 +854,7 @@ plot.variance_cube <- function(
                 msg = "plot type should be either map or hist")
     # plot the variance cube
     if (type == "map")
-        p <- .plot_variance_map(tile, labels, palette, rev)
+        p <- .plot_variance_map(tile, labels, palette, rev, tmap_options)
     else
         p <- .plot_variance_hist(tile)
 
@@ -816,6 +871,13 @@ plot.variance_cube <- function(
 #' @param  tile         Tiles to be plotted.
 #' @param  palette       An RColorBrewer palette
 #' @param  rev           Reverse the color order in the palette?
+#' @param  tmap_options  List with optional tmap parameters
+#'                       tmap_max_cells (default: 1e+06)
+#'                       tmap_graticules_labels_size (default: 0.7)
+#'                       tmap_legend_title_size (default: 1.5)
+#'                       tmap_legend_text_size (default: 1.2)
+#'                       tmap_legend_bg_color (default: "white")
+#'                       tmap_legend_bg_alpha (default: 0.5)
 #'
 #' @return               A plot object produced by the stars package
 #'                       with a map showing the uncertainty associated
@@ -830,9 +892,7 @@ plot.variance_cube <- function(
 #'     cube <- sits_cube(
 #'         source = "BDC",
 #'         collection = "MOD13Q1-6",
-#'         data_dir = data_dir,
-#'         delim = "_",
-#'         parse_info = c("X1", "tile", "band", "date")
+#'         data_dir = data_dir
 #'     )
 #'     # classify a data cube
 #'     probs_cube <- sits_classify(
@@ -849,7 +909,8 @@ plot.uncertainty_cube <- function(
         x, ...,
         tile = x$tile[[1]],
         palette = "RdYlGn",
-        rev = TRUE
+        rev = TRUE,
+        tmap_options = NULL
 ) {
     # precondition
     .check_chr_contains(
@@ -867,8 +928,10 @@ plot.uncertainty_cube <- function(
     # plot the data using tmap
     p <- .plot_false_color(tile = tile,
                            band = band,
+                           date = NULL,
                            palette  = palette,
-                           rev = rev)
+                           rev = rev,
+                           tmap_options = tmap_options)
 
     return(p)
 }
@@ -884,6 +947,13 @@ plot.uncertainty_cube <- function(
 #' @param  title           Title of the plot.
 #' @param  legend          Named vector that associates labels to colors.
 #' @param  palette         Alternative RColorBrewer palette
+#' @param  tmap_options    List with optional tmap parameters
+#'                         tmap_max_cells (default: 1e+06)
+#'                         tmap_graticules_labels_size (default: 0.7)
+#'                         tmap_legend_title_size (default: 1.5)
+#'                         tmap_legend_text_size (default: 1.2)
+#'                         tmap_legend_bg_color (default: "white")
+#'                         tmap_legend_bg_alpha (default: 0.5)
 #'
 #' @return                 A  color map, where each pixel has the color
 #'                         associated to a label, as defined by the legend
@@ -898,9 +968,7 @@ plot.uncertainty_cube <- function(
 #'     cube <- sits_cube(
 #'         source = "BDC",
 #'         collection = "MOD13Q1-6",
-#'         data_dir = data_dir,
-#'         delim = "_",
-#'         parse_info = c("X1", "tile", "band", "date")
+#'         data_dir = data_dir
 #'     )
 #'     # classify a data cube
 #'     probs_cube <- sits_classify(
@@ -919,7 +987,8 @@ plot.class_cube <- function(x, y, ...,
                             tile = x$tile[[1]],
                             title = "Classified Image",
                             legend = NULL,
-                            palette = "Spectral") {
+                            palette = "Spectral",
+                            tmap_options = NULL) {
     stopifnot(missing(y))
     # set caller to show in errors
     .check_set_caller("plot_class_cube")
@@ -950,7 +1019,10 @@ plot.class_cube <- function(x, y, ...,
     tile <- .cube_filter_tiles(cube = cube, tiles = tile)
 
     # plot class cube
-    .plot_class_image(tile, legend, palette)
+    .plot_class_image(tile = tile,
+                      legend = legend,
+                      palette = palette,
+                      tmap_options = tmap_options)
 }
 #' @title  Plot a false color image
 #' @name   .plot_false_color
@@ -961,12 +1033,28 @@ plot.class_cube <- function(x, y, ...,
 #' @param  tile          Tile to be plotted.
 #' @param  band          Band to be plotted.
 #' @param  date          Date to be plotted.
+#' @param  segments      List with segments to be shown (one per tile)
+#' @param  seg_color     Color to use for segment borders
 #' @param  palette       A sequential RColorBrewer palette
 #' @param  rev           Reverse the color palette?
+#' @param  tmap_options  List with optional tmap parameters
+#'                       tmap max_cells (default: 1e+06)
+#'                       tmap_graticules_labels_size (default: 0.7)
+#'                       tmap_legend_title_size (default: 1.5)
+#'                       tmap_legend_text_size (default: 1.2)
+#'                       tmap_legend_bg_color (default: "white")
+#'                       tmap_legend_bg_alpha (default: 0.5)
 #'
 #' @return               A plot object
 #'
-.plot_false_color <- function(tile, band, date = NULL, palette, rev) {
+.plot_false_color <- function(tile,
+                              band,
+                              date,
+                              segments = NULL,
+                              seg_color = NULL,
+                              palette,
+                              rev,
+                              tmap_options) {
 
     # verifies if stars package is installed
     .check_require_packages("stars")
@@ -991,7 +1079,8 @@ plot.class_cube <- function(x, y, ...,
     bw_file <- .tile_path(tile, band, date)
 
     # size of data to be read
-    size <- .plot_read_size(tile)
+    size <- .plot_read_size(tile = tile,
+                            tmap_options = tmap_options)
 
     # read file
     stars_obj <- stars::read_stars(
@@ -1004,7 +1093,38 @@ plot.class_cube <- function(x, y, ...,
     )
 
     # rescale the stars object
-    stars_obj <- stars_obj * .conf("raster_cube_scale_factor")
+    band_conf <- .tile_band_conf(tile = tile, band = band)
+    scale <- .scale(band_conf)
+    offset <- .offset(band_conf)
+    stars_obj <- stars_obj * scale + offset
+
+    # set the tmap options
+    labels_size <- as.numeric(.conf("tmap_graticules_labels_size"))
+    title_size  <- as.numeric(.conf("tmap_legend_title_size"))
+    text_size   <- as.numeric(.conf("tmap_legend_text_size"))
+    bg_color <- .conf("tmap_legend_bg_color")
+    bg_alpha <- as.numeric(.conf("tmap_legend_bg_alpha"))
+    # user specified tmap options
+    if (!purrr::is_null(tmap_options)) {
+        # graticules label size
+        if (!purrr::is_null(tmap_options[["tmap_graticules_labels_size"]]))
+            labels_size <- as.numeric(
+                tmap_options[["tmap_graticules_labels_size"]])
+        # legend title size
+        if (!purrr::is_null(tmap_options[["tmap_legend_title_size"]]))
+            title_size <- as.numeric(
+                tmap_options[["tmap_legend_title_size"]])
+        # legend text size
+        if (!purrr::is_null(tmap_options[["tmap_legend_text_size"]]))
+            text_size <- as.numeric(
+                tmap_options[["tmap_legend_text_size"]])
+        # tmap legend bg color
+        if (!purrr::is_null(tmap_options[["tmap_legend_bg_color"]]))
+            bg_color <- tmap_options[["tmap_legend_bg_color"]]
+        # tmap legend bg alpha
+        if (!purrr::is_null(tmap_options[["tmap_legend_bg_alpha"]]))
+            bg_alpha <- as.numeric(tmap_options[["tmap_legend_bg_alpha"]])
+    }
 
     p <- suppressMessages(
         tmap::tm_shape(stars_obj) +
@@ -1014,14 +1134,27 @@ plot.class_cube <- function(x, y, ...,
                 title = band,
                 midpoint = NA) +
             tmap::tm_graticules(
-                labels.size = 0.7
+                labels.size = labels_size
             )  +
             tmap::tm_compass() +
-            tmap::tm_layout(legend.title.size = 1.5,
-                            legend.text.size = 1.2,
-                            legend.bg.color = "white",
-                            legend.bg.alpha = 0.5)
+            tmap::tm_layout(legend.title.size = title_size,
+                            legend.text.size = text_size,
+                            legend.bg.color = bg_color,
+                            legend.bg.alpha = bg_alpha)
     )
+    # include segments
+    if (!purrr::is_null(segments)) {
+        tile_name <- tile$tile
+        .check_chr_within(
+            x = tile_name,
+            within = names(segments),
+            msg = "there are no segments for this tile"
+        )
+        # retrieve the segments for this tile
+        sf_seg <- segments[[tile_name]]
+        p <- p + tmap::tm_shape(sf_seg) +
+            tmap::tm_borders(col = seg_color, lwd = 0.2)
+    }
     return(p)
 }
 #' @title  Plot a classified image
@@ -1033,10 +1166,17 @@ plot.class_cube <- function(x, y, ...,
 #' @param  tile          Tile to be plotted.
 #' @param  legend        Legend for the classes
 #' @param  palette       A sequential RColorBrewer palette
+#' @param  tmap_options  List with optional tmap parameters
+#'                       tmap max_cells (default: 1e+06)
+#'                       tmap_graticules_labels_size (default: 0.7)
+#'                       tmap_legend_title_size (default: 1.5)
+#'                       tmap_legend_text_size (default: 1.2)
+#'                       tmap_legend_bg_color (default: "white")
+#'                       tmap_legend_bg_alpha (default: 0.5)
 #'
 #' @return               A plot object
 #'
-.plot_class_image <- function(tile, legend, palette) {
+.plot_class_image <- function(tile, legend, palette, tmap_options) {
 
     # verifies if stars package is installed
     .check_require_packages("stars")
@@ -1065,7 +1205,7 @@ plot.class_cube <- function(x, y, ...,
     )
     names(colors) <- seq_along(labels)
     # size of data to be read
-    size <- .plot_read_size(tile)
+    size <- .plot_read_size(tile = tile, tmap_options = tmap_options)
     # select the image to be plotted
     class_file <- .tile_path(tile)
 
@@ -1082,6 +1222,34 @@ plot.class_cube <- function(x, y, ...,
     # rename stars object
     stars_obj <- stats::setNames(stars_obj, "labels")
 
+    # set the tmap options
+    labels_size <- as.numeric(.conf("tmap_graticules_labels_size"))
+    title_size  <- as.numeric(.conf("tmap_legend_title_size"))
+    text_size   <- as.numeric(.conf("tmap_legend_text_size"))
+    bg_color <- .conf("tmap_legend_bg_color")
+    bg_alpha <- as.numeric(.conf("tmap_legend_bg_alpha"))
+    # user specified tmap options
+    if (!purrr::is_null(tmap_options)){
+        # graticules label size
+        if (!purrr::is_null(tmap_options[["tmap_graticules_labels_size"]]))
+            labels_size <- as.numeric(
+                tmap_options[["tmap_graticules_labels_size"]])
+        # legend title size
+        if (!purrr::is_null(tmap_options[["tmap_legend_title_size"]]))
+            title_size <- as.numeric(
+                tmap_options[["tmap_legend_title_size"]])
+        # legend text size
+        if (!purrr::is_null(tmap_options[["tmap_legend_text_size"]]))
+            text_size <- as.numeric(
+                tmap_options[["tmap_legend_text_size"]])
+        # tmap legend bg color
+        if (!purrr::is_null(tmap_options[["tmap_legend_bg_color"]]))
+            bg_color <- tmap_options[["tmap_legend_bg_color"]]
+        # tmap legend bg alpha
+        if (!purrr::is_null(tmap_options[["tmap_legend_bg_alpha"]]))
+            bg_alpha <- as.numeric(tmap_options[["tmap_legend_bg_alpha"]])
+    }
+
     # plot using tmap
     # tmap requires numbers, not names
     names(colors) <- seq_along(names(colors))
@@ -1092,16 +1260,16 @@ plot.class_cube <- function(x, y, ...,
                 palette = colors,
                 labels = labels) +
             tmap::tm_graticules(
-                labels.size = 0.7
+                labels.size = labels_size
             )  +
             tmap::tm_compass() +
             tmap::tm_layout(
                 legend.show = TRUE,
                 legend.outside = FALSE,
-                legend.title.size = 1.4,
-                legend.text.size = 1.1,
-                legend.bg.color = "white",
-                legend.bg.alpha = 0.5)
+                legend.title.size = title_size,
+                legend.text.size = text_size,
+                legend.bg.color = bg_color,
+                legend.bg.alpha = bg_alpha)
     )
     return(p)
 }
@@ -1114,10 +1282,17 @@ plot.class_cube <- function(x, y, ...,
 #' @param  labels_plot   Labels to be plotted
 #' @param  palette       A sequential RColorBrewer palette
 #' @param  rev           Reverse the color palette?
+#' @param  tmap_options  List with optional tmap parameters
+#'                       tmap max_cells (default: 1e+06)
+#'                       tmap_graticules_labels_size (default: 0.7)
+#'                       tmap_legend_title_size (default: 1.5)
+#'                       tmap_legend_text_size (default: 1.2)
+#'                       tmap_legend_bg_color (default: "white")
+#'                       tmap_legend_bg_alpha (default: 0.5)
 #'
 #' @return               A plot object
 #'
-.plot_probs <- function(tile, labels_plot, palette, rev) {
+.plot_probs <- function(tile, labels_plot, palette, rev, tmap_options) {
 
     # verifies if stars package is installed
     .check_require_packages("stars")
@@ -1150,7 +1325,8 @@ plot.class_cube <- function(x, y, ...,
                     msg = "labels not in cube")
 
     # size of data to be read
-    size <- .plot_read_size(tile)
+    size <- .plot_read_size(tile = tile,
+                            tmap_options = tmap_options)
 
     # get the path
     probs_path <- .tile_path(tile)
@@ -1175,6 +1351,34 @@ plot.class_cube <- function(x, y, ...,
     # select stars bands to be plotted
     bds <- as.numeric(names(labels[labels %in% labels_plot]))
 
+    # set the tmap options
+    labels_size <- as.numeric(.conf("tmap_graticules_labels_size"))
+    title_size  <- as.numeric(.conf("tmap_legend_title_size"))
+    text_size   <- as.numeric(.conf("tmap_legend_text_size"))
+    bg_color <- .conf("tmap_legend_bg_color")
+    bg_alpha <- as.numeric(.conf("tmap_legend_bg_alpha"))
+    # user specified tmap options
+    if (!purrr::is_null(tmap_options)){
+        # graticules label size
+        if (!purrr::is_null(tmap_options[["tmap_graticules_labels_size"]]))
+            labels_size <- as.numeric(
+                tmap_options[["tmap_graticules_labels_size"]])
+        # legend title size
+        if (!purrr::is_null(tmap_options[["tmap_legend_title_size"]]))
+            title_size <- as.numeric(
+                tmap_options[["tmap_legend_title_size"]])
+        # legend text size
+        if (!purrr::is_null(tmap_options[["tmap_legend_text_size"]]))
+            text_size <- as.numeric(
+                tmap_options[["tmap_legend_text_size"]])
+        # tmap legend bg color
+        if (!purrr::is_null(tmap_options[["tmap_legend_bg_color"]]))
+            bg_color <- tmap_options[["tmap_legend_bg_color"]]
+        # tmap legend bg alpha
+        if (!purrr::is_null(tmap_options[["tmap_legend_bg_alpha"]]))
+            bg_alpha <- as.numeric(tmap_options[["tmap_legend_bg_alpha"]])
+    }
+
     p <- tmap::tm_shape(probs_st[, , , bds]) +
         tmap::tm_raster(style = "cont",
                         palette = palette,
@@ -1184,10 +1388,10 @@ plot.class_cube <- function(x, y, ...,
         tmap::tm_compass() +
         tmap::tm_layout(legend.show = TRUE,
                         legend.outside = FALSE,
-                        legend.bg.color = "white",
-                        legend.bg.alpha = 0.5,
-                        legend.title.size = 1.5,
-                        legend.text.size = 1.2,
+                        legend.bg.color = bg_color,
+                        legend.bg.alpha = bg_alpha,
+                        legend.title.size = title_size,
+                        legend.text.size = text_size,
                         outer.margins = 0)
 
     return(p)
@@ -1201,10 +1405,18 @@ plot.class_cube <- function(x, y, ...,
 #' @param  labels_plot   Labels to be plotted
 #' @param  palette       A sequential RColorBrewer palette
 #' @param  rev           Reverse the color palette?
+#' @param  tmap_options  List with optional tmap parameters
+#'                       tmap max_cells (default: 1e+06)
+#'                       tmap_graticules_labels_size (default: 0.7)
+#'                       tmap_legend_title_size (default: 1.5)
+#'                       tmap_legend_text_size (default: 1.2)
+#'                       tmap_legend_bg_color (default: "white")
+#'                       tmap_legend_bg_alpha (default: 0.5)
 #'
 #' @return               A plot object
 #'
-.plot_variance_map <- function(tile, labels_plot, palette, rev) {
+.plot_variance_map <- function(tile, labels_plot, palette, rev,
+                               tmap_options) {
 
     # verifies if stars package is installed
     .check_require_packages("stars")
@@ -1237,7 +1449,8 @@ plot.class_cube <- function(x, y, ...,
                     msg = "labels not in cube")
 
     # size of data to be read
-    size <- .plot_read_size(tile)
+    size <- .plot_read_size(tile = tile,
+                            tmap_options = tmap_options)
 
     # get the path
     var_path <- .tile_path(tile)
@@ -1262,6 +1475,35 @@ plot.class_cube <- function(x, y, ...,
     # select stars bands to be plotted
     bds <- as.numeric(names(labels[labels %in% labels_plot]))
 
+    # set the tmap options
+    labels_size <- as.numeric(.conf("tmap_graticules_labels_size"))
+    title_size  <- as.numeric(.conf("tmap_legend_title_size"))
+    text_size   <- as.numeric(.conf("tmap_legend_text_size"))
+    bg_color    <- .conf("tmap_legend_bg_color")
+    bg_alpha    <- as.numeric(.conf("tmap_legend_bg_alpha"))
+
+    # user specified tmap options
+    if (!purrr::is_null(tmap_options)){
+        # graticules label size
+        if (!purrr::is_null(tmap_options[["tmap_graticules_labels_size"]]))
+            labels_size <- as.numeric(
+                tmap_options[["tmap_graticules_labels_size"]])
+        # legend title size
+        if (!purrr::is_null(tmap_options[["tmap_legend_title_size"]]))
+            title_size <- as.numeric(
+                tmap_options[["tmap_legend_title_size"]])
+        # legend text size
+        if (!purrr::is_null(tmap_options[["tmap_legend_text_size"]]))
+            text_size <- as.numeric(
+                tmap_options[["tmap_legend_text_size"]])
+        # tmap legend bg color
+        if (!purrr::is_null(tmap_options[["tmap_legend_bg_color"]]))
+            bg_color <- tmap_options[["tmap_legend_bg_color"]]
+        # tmap legend bg alpha
+        if (!purrr::is_null(tmap_options[["tmap_legend_bg_alpha"]]))
+            bg_alpha <- as.numeric(tmap_options[["tmap_legend_bg_alpha"]])
+    }
+
     p <- tmap::tm_shape(var_st[, , , bds]) +
         tmap::tm_raster(style = "cont",
                         palette = palette,
@@ -1271,10 +1513,10 @@ plot.class_cube <- function(x, y, ...,
         tmap::tm_compass() +
         tmap::tm_layout(legend.show = TRUE,
                         legend.outside = FALSE,
-                        legend.bg.color = "white",
-                        legend.bg.alpha = 0.5,
-                        legend.title.size = 1.5,
-                        legend.text.size = 1.2,
+                        legend.bg.color = bg_color,
+                        legend.bg.alpha = bg_alpha,
+                        legend.title.size = title_size,
+                        legend.text.size = text_size,
                         outer.margins = 0)
 
     return(p)
@@ -1300,7 +1542,7 @@ plot.class_cube <- function(x, y, ...,
     nrows <- .tile_nrows(tile)
     ncols <- .tile_ncols(tile)
     # sample the pixels
-    n_samples <- as.integer(nrows / 10 * ncols / 10)
+    n_samples <- as.integer(nrows / 5 * ncols / 5)
     points <- sf::st_sample(sf_cube, size = n_samples)
     points <- sf::st_coordinates(points)
     # get the r object
@@ -1351,10 +1593,26 @@ plot.class_cube <- function(x, y, ...,
 #' @param  green         Band to be plotted in green
 #' @param  blue          Band to be plotted in blue
 #' @param  date          Date to be plotted
+#' @param  segments      List with segments to be shown (one per tile)
+#' @param  seg_color     Color to use for segment borders
+#' @param  tmap_options  List with optional tmap parameters
+#'                       tmap max_cells (default: 1e+06)
+#'                       tmap_graticules_labels_size (default: 0.7)
+#'                       tmap_legend_title_size (default: 1.5)
+#'                       tmap_legend_text_size (default: 1.2)
+#'                       tmap_legend_bg_color (default: "white")
+#'                       tmap_legend_bg_alpha (default: 0.5)
 #'
 #' @return               A plot object
 #'
-.plot_rgb <- function(tile, red, green, blue, date) {
+.plot_rgb <- function(tile,
+                      red,
+                      green,
+                      blue,
+                      date,
+                      segments = NULL,
+                      seg_color = NULL,
+                      tmap_options) {
 
     # verifies if stars package is installed
     .check_require_packages("stars")
@@ -1367,7 +1625,8 @@ plot.class_cube <- function(x, y, ...,
     blue_file  <- .tile_path(tile, blue, date)
 
     # size of data to be read
-    size <- .plot_read_size(tile)
+    size <- .plot_read_size(tile = tile,
+                            tmap_options = tmap_options)
     # read raster data as a stars object with separate RGB bands
     rgb_st <- stars::read_stars(
         c(red_file, green_file, blue_file),
@@ -1394,6 +1653,20 @@ plot.class_cube <- function(x, y, ...,
          tmap::tm_graticules() +
          tmap::tm_compass()
 
+    # include segments
+    if (!purrr::is_null(segments)) {
+        tile_name <- tile$tile
+        .check_chr_within(
+            x = tile_name,
+            within = names(segments),
+            msg = "there are no segments for this tile"
+        )
+        # retrieve the segments for this tile
+        sf_seg <- segments[[tile_name]]
+        p <- p + tmap::tm_shape(sf_seg) +
+            tmap::tm_borders(col = seg_color, lwd = 0.2)
+    }
+
     return(p)
 }
 #' @title  Return the cell size for the image to be reduced for plotting
@@ -1403,19 +1676,29 @@ plot.class_cube <- function(x, y, ...,
 #' @author Gilberto Camara, \email{gilberto.camara@@inpe.br}
 #'
 #' @param  tile       Tile to be plotted.
+#' @param  tmap_options  List with optional tmap parameters
+#'                       tmap max_cells (default: 1e+06)
+#'                       tmap_graticules_labels_size (default: 0.7)
+#'                       tmap_legend_title_size (default: 1.5)
+#'                       tmap_legend_text_size (default: 1.2)
+#'                       tmap_legend_bg_color (default: "white")
+#'                       tmap_legend_bg_alpha (default: 0.5)
 #' @return            Cell size for x and y coordinates.
 #'
 #'
-.plot_read_size <- function(tile) {
+.plot_read_size <- function(tile, tmap_options) {
 
     # get the maximum number of bytes to be displayed
-    max_cells <- as.numeric(.conf("tmap_max_cells"))
+    if (!purrr::is_null(tmap_options[["tmap_max_cells"]]))
+        max_cells <- tmap_options[["tmap_max_cells"]]
+    else
+        max_cells <- as.numeric(.conf("tmap_max_cells"))
     max_raster <- c(plot = max_cells, view = max_cells)
     # set the options for tmap
     tmap::tmap_options(max.raster = max_raster)
     # numbers of nrows and ncols
-    nrows <- .tile_nrows(tile)
-    ncols <- .tile_ncols(tile)
+    nrows <- max(.tile_nrows(tile))
+    ncols <- max(.tile_ncols(tile))
 
     # do we need to compress?
     ratio <- max((nrows * ncols / max_cells), 1)
@@ -1503,8 +1786,7 @@ plot.rfor_model <- function(x, y, ...) {
 #' }
 #' @export
 #'
-plot.sits_accuracy <- function(x, y, ...,
-                                      title = "Confusion matrix") {
+plot.sits_accuracy <- function(x, y, ..., title = "Confusion matrix") {
     stopifnot(missing(y))
     data <- x
     if (!inherits(data, "sits_accuracy")) {
@@ -1829,9 +2111,9 @@ plot.torch_model <- function(x, y, ...) {
 #'
 #' @return              The dendrogram object.
 .plot_dendrogram <- function(data,
-                                  cluster,
-                                  cutree_height,
-                                  palette) {
+                             cluster,
+                             cutree_height,
+                             palette) {
 
     # set caller to show in errors
     .check_set_caller(".plot_dendrogram")
