@@ -12,13 +12,11 @@
 #'
 #' @param  cube              Probability data cube.
 #' @param  window_size       Size of the neighborhood.
-#' @param  neigh_fraction    Fraction of neighbors with highest probability
+#' @param  neigh_fraction    Fraction of neighbors with high probabilities
 #'                           to be used in Bayesian inference.
 #' @param  smoothness        Estimated variance of logit of class probabilities
 #'                           (Bayesian smoothing parameter). It can be either
 #'                           a vector or a scalar.
-#' @param  min_samples       Minimum number of samples to estimate normal
-#'                           probability distribution for Bayesian inference.
 #' @param  multicores        Number of cores to run the smoothing function
 #' @param  memsize           Maximum overall memory (in GB) to run the
 #'                           smoothing.
@@ -40,9 +38,7 @@
 #'     cube <- sits_cube(
 #'         source = "BDC",
 #'         collection = "MOD13Q1-6",
-#'         data_dir = data_dir,
-#'         delim = "_",
-#'         parse_info = c("X1", "tile", "band", "date")
+#'         data_dir = data_dir
 #'     )
 #'     # classify a data cube
 #'     probs_cube <- sits_classify(
@@ -63,10 +59,9 @@
 #' }
 #' @export
 sits_smooth <- function(cube,
-                        window_size = 9,
+                        window_size = 7,
                         neigh_fraction = 0.5,
                         smoothness = 10,
-                        min_samples = 25,
                         memsize = 4,
                         multicores = 2,
                         output_dir,
@@ -88,8 +83,9 @@ sits_smooth <- function(cube,
     # Check smoothness
     .check_smoothness(smoothness, nlabels)
     # Prepare smoothness parameter
-    smoothness <- diag(smoothness, nrow = nlabels, ncol = nlabels)
-
+    if (length(smoothness == 1)) {
+        smoothness <- rep(smoothness, nlabels)
+    }
     # Get block size
     block <- .raster_file_blocksize(.raster_open_rast(.tile_path(cube)))
     # Overlapping pixels
@@ -125,7 +121,6 @@ sits_smooth <- function(cube,
         window_size = window_size,
         neigh_fraction = neigh_fraction,
         smoothness = smoothness,
-        min_samples = min_samples,
         multicores = multicores,
         memsize = memsize,
         output_dir = output_dir,
