@@ -93,8 +93,10 @@ sits_kfold_validate <- function(samples,
     if (multicores > 1 && .Platform$OS.type == "windows" &&
         "optimizer" %in% ls(environment(ml_method))) {
         multicores <- 1
-        warning("sits_kfold_validate() works only with 1 core in Windows OS.",
-                call. = FALSE, immediate. = TRUE)
+        if (.check_warnings())
+            warning("sits_kfold_validate() works only with 1 core in Windows OS.",
+                call. = FALSE, immediate. = TRUE
+            )
     }
 
     # Get labels from samples
