@@ -5,8 +5,9 @@
         sprintf(
             "Loaded sits v%s.
         See ?sits for help, citation(\"sits\") for use in publication.
-        See demo(package = \"sits\") for examples.",
-            utils::packageDescription("sits")$Version
+        Documentation avaliable in %s.",
+            utils::packageDescription("sits")$Version,
+            "https://e-sensing.github.io/sitsbook/"
         )
     )
 }
