@@ -5,24 +5,27 @@ test_that("Suggested samples have low confidence, high entropy", {
     cube <- sits_cube(
         source = "BDC",
         collection = "MOD13Q1-6",
-        data_dir = data_dir,
-        delim = "_",
-        parse_info = c("X1", "tile", "band", "date")
+        data_dir = data_dir
     )
     set.seed(123)
     rfor_model <- sits_train(samples_modis_ndvi,
         ml_method = sits_xgboost(verbose = FALSE)
     )
+    output_dir <- paste0(tempdir(), "/al")
+    if (!dir.exists(output_dir)) {
+        dir.create(output_dir)
+    }
     probs_cube <- sits_classify(
         cube,
         ml_model = rfor_model,
-        output_dir = tempdir(),
-        memsize = 4, multicores = 2
+        output_dir = output_dir,
+        memsize = 4,
+        multicores = 2
     )
     uncert_cube <- sits_uncertainty(
         probs_cube,
         type = "least",
-        output_dir = tempdir()
+        output_dir = output_dir
     )
 
     # Get sample suggestions.
@@ -41,6 +44,9 @@ test_that("Suggested samples have low confidence, high entropy", {
     )))
     expect_true(all(samples_df[["label"]] == "NoClass"))
     expect_true(all(samples_df[["uncertainty"]] >= 0.3))
+
+    unlink(probs_cube$file_info[[1]]$path)
+    unlink(uncert_cube$file_info[[1]]$path)
 })
 
 test_that("Increased samples have high confidence, low entropy", {
@@ -50,17 +56,19 @@ test_that("Increased samples have high confidence, low entropy", {
     cube <- sits_cube(
         source = "BDC",
         collection = "MOD13Q1-6",
-        data_dir = data_dir,
-        delim = "_",
-        parse_info = c("X1", "tile", "band", "date")
+        data_dir = data_dir
     )
     rfor_model <- sits_train(samples_modis_ndvi,
         ml_method = sits_rfor()
     )
+    output_dir <- paste0(tempdir(), "/al_2")
+    if (!dir.exists(output_dir)) {
+        dir.create(output_dir)
+    }
     probs_cube <- sits_classify(
         cube,
         ml_model = rfor_model,
-        output_dir = tempdir(),
+        output_dir = output_dir,
         memsize = 4, multicores = 2
     )
     # Get sample suggestions based on high confidence
@@ -84,4 +92,5 @@ test_that("Increased samples have high confidence, low entropy", {
         "start_date", "end_date",
         "label", "confidence"
     )))
+    unlink(probs_cube$file_info[[1]]$path)
 })
