@@ -40,3 +40,13 @@ test_that("Relabel cubes", {
     expect_true("Queimadas" %in% sits_labels(ro_class))
     expect_true("Floresta" %in% sits_labels(ro_class))
 })
+
+test_that("Models and patters", {
+    lab <- sits_patterns(cerrado_2classes) %>%
+        sits_labels()
+    expect_true(all(lab %in% c("Cerrado", "Pasture")))
+
+    rfor_model <- sits_train(samples_modis_ndvi, sits_rfor())
+    lab2 <- sits_labels(rfor_model)
+    expect_true(all(lab2 %in% c("Cerrado", "Pasture", "Forest", "Soy_Corn")))
+})
